@@ -329,6 +329,9 @@ fn main()  {
         let mut transfers_gene = vec![]; // Transferts de genes
         let mut transfers_para = vec![]; // Transferts de parasites(ou symbiotes)
 
+        // Gestion de l'optiopn free_living dans le cas d'une
+        let free_living_3l = options.free_living;
+        options.free_living = false;
         //
         // GENE - PARASITE STUFF
         //
@@ -435,6 +438,7 @@ fn main()  {
 
         // Reset the option
         options.thickness_flag = false;
+        options.free_living = free_living_3l;
 
         // If  the option -u is on :
         if thickness_flag_2nd {
@@ -560,20 +564,9 @@ fn main()  {
             reset_pos(&mut path_genes[i]);
             i = i + 1;
         }
-        // PATCH POURRI je passe le free_living a false
-        // car on ne veut pas recreer une branche free_living
-        // dans l'arbre d'espece
-		// les sortoes mapped_2 et mapped_3 ne sont pas jolies
-        // Attention, ca marche avec light_phylogeny = "0.31.0"
-        // A l'avenir on va essayer de traiter ça dans  light_phylogeny
-        options.free_living = false;
-
-        // if thickness_flag_1st {
-        // reset_pos(&mut selected_gene_trees[0]);
-        // }
-
         // Reset the option
         options.thickness_flag = false;
+        options.free_living = false;
         //  option -t is on
         if thickness_flag_1st {
             options.thickness_flag = true;
@@ -637,7 +630,8 @@ fn main()  {
                 mapped_gene_transfers.push(val);
             }
         }
-
+        // Reset the option
+        options.free_living = free_living_3l;
         // attention on ne remape pas
         recphyloxml_processing(&mut tree_host_pipe, &mut path_para_trees, &mut options, &config,
             false, &mapped_gene_transfers,outfile_mapped_2);
@@ -677,6 +671,8 @@ fn main()  {
             reset_pos(&mut path_genes[i]);
             i = i + 1;
         }
+        // Reset the option
+        options.free_living = false;
         recphyloxml_processing(&mut tree_host_pipe, &mut path_genes, &mut options, &config,
             true, &vec![],outfile_mapped_3);
         let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_3.svg".to_string());
